@@ -141,7 +141,7 @@ static int dns_query(const char *name, int type, int flags,
 {
     HEADER *reply_header;
     int     len;
-    unsigned long saved_options = _res.options;
+    unsigned long saved_options;
 
     /*
      * Initialize the name service.
@@ -160,7 +160,8 @@ static int dns_query(const char *name, int type, int flags,
 
     if ((flags & USER_FLAGS) != flags)
 	msg_panic("dns_query: bad flags: %d", flags);
-    _res.options &= ~(USER_FLAGS);
+    saved_options = (_res.options & USER_FLAGS);
+    _res.options &= ~saved_options;
     _res.options |= flags;
 
     /*
@@ -168,7 +169,8 @@ static int dns_query(const char *name, int type, int flags,
      * only if the name server told us so.
      */
     len = res_search((char *) name, C_IN, type, reply->buf, sizeof(reply->buf));
-    _res.options = saved_options;
+    _res.options &= ~flags;
+    _res.options |= saved_options;
     if (len < 0) {
 	if (why)
 	    vstring_sprintf(why, "Host or domain name not found. "
