@@ -6,8 +6,7 @@
 /* SYNOPSIS
 /*	\fBflush\fR [generic Postfix daemon options]
 /* DESCRIPTION
-/*	The \fBflush\fR(8) server maintains a record of deferred
-/*	mail by destination.
+/*	The flush server maintains a record of deferred mail by destination.
 /*	This information is used to improve the performance of the SMTP
 /*	\fBETRN\fR request, and of its command-line equivalent,
 /*	"\fBsendmail -qR\fR" or "\fBpostqueue -f\fR".
@@ -28,7 +27,7 @@
 /*
 /*	This server implements the following requests:
 /* .IP "\fBadd\fI sitename queueid\fR"
-/*	Inform the \fBflush\fR(8) server that the message with the specified
+/*	Inform the fast flush server that the message with the specified
 /*	queue ID is queued for the specified destination.
 /* .IP "\fBsend\fI sitename\fR"
 /*	Request delivery of mail that is queued for the specified
@@ -47,7 +46,7 @@
 /* SECURITY
 /* .ad
 /* .fi
-/*	The \fBflush\fR(8) server is not security-sensitive. It does not
+/*	The fast flush server is not security-sensitive. It does not
 /*	talk to the network, and it does not talk to local users.
 /*	The fast flush server can run chrooted at fixed low privilege.
 /* DIAGNOSTICS
@@ -61,7 +60,7 @@
 /*	\fBmaster.cf\fR configuration file.
 /*
 /*	Upon receipt of a request to deliver mail for an eligible
-/*	destination, the \fBflush\fR(8) server requests delivery of all messages
+/*	destination, the \fBflush\fR server requests delivery of all messages
 /*	that are listed in that destination's logfile, regardless of the
 /*	recipients of those messages. This is not an issue for mail
 /*	that is sent to a \fBrelay_domains\fR destination because
@@ -69,12 +68,12 @@
 /* CONFIGURATION PARAMETERS
 /* .ad
 /* .fi
-/*	Changes to \fBmain.cf\fR are picked up automatically as \fBflush\fR(8)
+/*	Changes to \fBmain.cf\fR are picked up automatically as flush(8)
 /*	processes run for only a limited amount of time. Use the command
 /*	"\fBpostfix reload\fR" to speed up a change.
 /*
 /*	The text below provides only a parameter summary. See
-/*	\fBpostconf\fR(5) for more details including examples.
+/*	postconf(5) for more details including examples.
 /* .IP "\fBconfig_directory (see 'postconf -d' output)\fR"
 /*	The default location of the Postfix main.cf and master.cf
 /*	configuration files.
@@ -147,7 +146,6 @@
 
 #include <sys_defs.h>
 #include <sys/stat.h>
-#include <sys/time.h>
 #include <unistd.h>
 #include <stdlib.h>
 #include <utime.h>
@@ -480,11 +478,6 @@ static int flush_send_path(const char *path, int how)
     if (count > 0 && ftruncate(vstream_fileno(log), (off_t) 0) < 0)
 	msg_fatal("%s: truncate fast flush logfile %s: %m", myname, path);
 
-    /*
-     * Workaround for noatime mounts. Use futimes() if available.
-     */
-    (void) utimes(VSTREAM_PATH(log), (struct timeval *) 0);
-
     /*
      * Request delivery and clean up.
      */
