@@ -147,7 +147,6 @@ void    resolve_clnt(const char *class, const char *addr, RESOLVE_REPLY *reply)
 {
     char   *myname = "resolve_clnt";
     VSTREAM *stream;
-    int     server_flags;
 
     /*
      * One-entry cache.
@@ -214,12 +213,11 @@ void    resolve_clnt(const char *class, const char *addr, RESOLVE_REPLY *reply)
 		       ATTR_TYPE_END) != 0
 	    || vstream_fflush(stream)
 	    || attr_scan(stream, ATTR_FLAG_STRICT,
-			 ATTR_TYPE_NUM, MAIL_ATTR_FLAGS, &server_flags,
 		       ATTR_TYPE_STR, MAIL_ATTR_TRANSPORT, reply->transport,
 			 ATTR_TYPE_STR, MAIL_ATTR_NEXTHOP, reply->nexthop,
 			 ATTR_TYPE_STR, MAIL_ATTR_RECIP, reply->recipient,
 			 ATTR_TYPE_NUM, MAIL_ATTR_FLAGS, &reply->flags,
-			 ATTR_TYPE_END) != 5) {
+			 ATTR_TYPE_END) != 4) {
 	    if (msg_verbose || (errno != EPIPE && errno != ENOENT))
 		msg_warn("problem talking to service %s: %m",
 			 var_rewrite_service);
@@ -237,9 +235,6 @@ void    resolve_clnt(const char *class, const char *addr, RESOLVE_REPLY *reply)
 			 IFSET(RESOLVE_CLASS_VIRTUAL, "virtual"),
 			 IFSET(RESOLVE_CLASS_RELAY, "relay"),
 			 IFSET(RESOLVE_CLASS_DEFAULT, "default"));
-	    /* Server-requested disconnect. */
-	    if (server_flags != 0)
-		clnt_stream_recover(rewrite_clnt_stream);
 	    if (STR(reply->transport)[0] == 0)
 		msg_warn("%s: null transport result for: <%s>", myname, addr);
 	    else if (STR(reply->recipient)[0] == 0 && *addr != 0)
