@@ -6,7 +6,7 @@
 /* SYNOPSIS
 /*	\fBpostcat\fR [\fB-oqv\fR] [\fB-c \fIconfig_dir\fR] [\fIfiles\fR...]
 /* DESCRIPTION
-/*	The \fBpostcat\fR(1) command prints the contents of the named
+/*	The \fBpostcat\fR command prints the contents of the named
 /*	\fIfiles\fR in human-readable form. The files are expected
 /*	to be in Postfix queue file format. If no
 /*	\fIfiles\fR are specified on the command line, the program
@@ -40,7 +40,7 @@
 /*	this program.
 /*
 /*	The text below provides only a parameter summary. See
-/*	\fBpostconf\fR(5) for more details including examples.
+/*	postconf(5) for more details including examples.
 /* .IP "\fBconfig_directory (see 'postconf -d' output)\fR"
 /*	The default location of the Postfix main.cf and master.cf
 /*	configuration files.
@@ -136,7 +136,8 @@ static void postcat(VSTREAM *fp, VSTRING *buffer, int flags)
 	    vstream_printf("*** ENVELOPE RECORDS %s ***\n", VSTREAM_PATH(fp));
 	    first = 0;
 	}
-	if (prev_type == REC_TYPE_CONT && !TEXT_RECORD(rec_type))
+	if (prev_type == REC_TYPE_CONT && in_message && !msg_verbose
+	    && ((flags & PC_FLAG_OFFSET) != 0 || !TEXT_RECORD(rec_type)))
 	    VSTREAM_PUTCHAR('\n');
 	if (flags & PC_FLAG_OFFSET)
 	    vstream_printf("%9lu ", (unsigned long) offset);
@@ -148,15 +149,11 @@ static void postcat(VSTREAM *fp, VSTRING *buffer, int flags)
 			   asctime(localtime(&time)));
 	    break;
 	case REC_TYPE_CONT:			/* REC_TYPE_FILT collision */
-	    if (!in_message) 
-		vstream_printf("%s: ", rec_type_name(rec_type));
-	    else if (msg_verbose)
+	    if (msg_verbose)
 		vstream_printf("unterminated_text: ");
 	    vstream_fwrite(VSTREAM_OUT, STR(buffer), LEN(buffer));
-	    if (!in_message || msg_verbose || (flags & PC_FLAG_OFFSET) != 0) {
-		rec_type = 0;
+	    if (msg_verbose)
 		VSTREAM_PUTCHAR('\n');
-	    }
 	    break;
 	case REC_TYPE_NORM:
 	    if (msg_verbose)
