@@ -121,6 +121,8 @@
 #include <quote_821_local.h>
 #include <mail_proto.h>
 #include <mime_state.h>
+#include <ehlo_mask.h>
+#include <maps.h>
 
 /* Application-specific. */
 
@@ -227,6 +229,8 @@ int     smtp_helo(SMTP_STATE *state, int misc_flags)
 	0, 0,
     };
     SOCKOPT_SIZE optlen;
+    const char *ehlo_words;
+    int     discard_mask;
 
     /*
      * Prepare for disaster.
@@ -302,6 +306,17 @@ int     smtp_helo(SMTP_STATE *state, int misc_flags)
 	return (0);
     }
 
+    /*
+     * Determine what server EHLO keywords to ignore, typically to avoid
+     * inter-operability problems.
+     */
+    if (smtp_ehlo_dis_maps == 0
+	|| (ehlo_words = maps_find(smtp_ehlo_dis_maps, state->session->addr, 0)) == 0)
+	ehlo_words = var_smtp_ehlo_dis_words;
+    discard_mask = ehlo_mask(ehlo_words);
+    if (discard_mask)
+	msg_info("discarding EHLO keywords: %s", str_ehlo_mask(discard_mask));
+
     /*
      * Pick up some useful features offered by the SMTP server. XXX Until we
      * have a portable routine to convert from string to off_t with proper
@@ -315,29 +330,34 @@ int     smtp_helo(SMTP_STATE *state, int misc_flags)
     lines = resp->str;
     while ((words = mystrtok(&lines, "\n")) != 0) {
 	if (mystrtok(&words, "- ") && (word = mystrtok(&words, " \t=")) != 0) {
-	    if (strcasecmp(word, "8BITMIME") == 0)
-		session->features |= SMTP_FEATURE_8BITMIME;
-	    else if (strcasecmp(word, "PIPELINING") == 0)
-		session->features |= SMTP_FEATURE_PIPELINING;
-	    else if (strcasecmp(word, "XFORWARD") == 0)
-		while ((word = mystrtok(&words, " \t")) != 0)
-		    session->features |= name_code(xforward_features,
+	    if (strcasecmp(word, "8BITMIME") == 0) {
+		if ((discard_mask & EHLO_MASK_8BITMIME) == 0)
+		    session->features |= SMTP_FEATURE_8BITMIME;
+	    } else if (strcasecmp(word, "PIPELINING") == 0) {
+		if ((discard_mask & EHLO_MASK_PIPELINING) == 0)
+		    session->features |= SMTP_FEATURE_PIPELINING;
+	    } else if (strcasecmp(word, "XFORWARD") == 0) {
+		if ((discard_mask & EHLO_MASK_XFORWARD) == 0)
+		    while ((word = mystrtok(&words, " \t")) != 0)
+			session->features |= name_code(xforward_features,
 						 NAME_CODE_FLAG_NONE, word);
-	    else if (strcasecmp(word, "SIZE") == 0) {
-		session->features |= SMTP_FEATURE_SIZE;
-		if ((word = mystrtok(&words, " \t")) != 0) {
-		    if (!alldig(word))
-			msg_warn("bad size limit \"%s\" in EHLO reply from %s",
-				 word, session->namaddr);
-		    else
-			session->size_limit = off_cvt_string(word);
+	    } else if (strcasecmp(word, "SIZE") == 0) {
+		if ((discard_mask & EHLO_MASK_SIZE) == 0) {
+		    session->features |= SMTP_FEATURE_SIZE;
+		    if ((word = mystrtok(&words, " \t")) != 0) {
+			if (!alldig(word))
+			    msg_warn("bad EHLO SIZE limit \"%s\" from %s",
+				     word, session->namaddr);
+			else
+			    session->size_limit = off_cvt_string(word);
+		    }
 		}
-	    }
 #ifdef USE_SASL_AUTH
-	    else if (var_smtp_sasl_enable && strcasecmp(word, "AUTH") == 0)
-		smtp_sasl_helo_auth(session, words);
+	    } else if (var_smtp_sasl_enable && strcasecmp(word, "AUTH") == 0) {
+		if ((discard_mask & EHLO_MASK_AUTH) == 0)
+		    smtp_sasl_helo_auth(session, words);
 #endif
-	    else if (strcasecmp(word, var_myhostname) == 0) {
+	    } else if (strcasecmp(word, var_myhostname) == 0) {
 		if (misc_flags & SMTP_MISC_FLAG_LOOP_DETECT) {
 		    msg_warn("host %s replied to HELO/EHLO with my own hostname %s",
 			     session->namaddr, var_myhostname);
