@@ -7,8 +7,7 @@
 /*	\fBvirtual\fR [generic Postfix daemon options]
 /* DESCRIPTION
 /*	The \fBvirtual\fR(8) delivery agent is designed for virtual mail
-/*	hosting services. Originally based on the Postfix \fBlocal\fR(8)
-/*	delivery
+/*	hosting services. Originally based on the Postfix local(8) delivery
 /*	agent, this agent looks up recipients with map lookups of their
 /*	full recipient address, instead of using hard-coded unix password
 /*	file lookups of the address local part only.
@@ -37,7 +36,7 @@
 /*	is delivered in UNIX mailbox format.   This format stores multiple
 /*	messages in one textfile.
 /*
-/*	The \fBvirtual\fR(8) delivery agent prepends a "\fBFrom \fIsender
+/*	The \fBvirtual\fR delivery agent prepends a "\fBFrom \fIsender
 /*	time_stamp\fR" envelope header to each message, prepends a
 /*	\fBDelivered-To:\fR message header with the envelope recipient
 /*	address,
@@ -56,7 +55,7 @@
 /*	When the mailbox location ends in \fB/\fR, the message is delivered
 /*	in qmail \fBmaildir\fR format. This format stores one message per file.
 /*
-/*	The \fBvirtual\fR(8) delivery agent prepends a \fBDelivered-To:\fR
+/*	The \fBvirtual\fR delivery agent daemon prepends a \fBDelivered-To:\fR
 /*	message header with the final envelope recipient address,
 /*	prepends an \fBX-Original-To:\fR header with the recipient address as
 /*	given to Postfix, and prepends a
@@ -107,18 +106,9 @@
 /* SECURITY
 /* .ad
 /* .fi
-/*	The \fBvirtual\fR(8) delivery agent is not security sensitive, provided
+/*	The virtual delivery agent is not security sensitive, provided
 /*	that the lookup tables with recipient user/group ID information are
 /*	adequately protected. This program is not designed to run chrooted.
-/*
-/*	The \fBvirtual\fR(8) delivery agent disallows regular expression
-/*	substitution of $1 etc. in regular expression lookup tables,
-/*	because that would open a security hole.
-/*
-/*	The \fBvirtual\fR(8) delivery agent will silently ignore requests
-/*	to use the \fBproxymap\fR(8) server. Instead it will open the
-/*	table directly. Before Postfix version 2.2, the virtual
-/*	delivery agent will terminate with a fatal error.
 /* STANDARDS
 /*	RFC 822 (ARPA Internet Text Messages)
 /* DIAGNOSTICS
@@ -143,30 +133,29 @@
 /* CONFIGURATION PARAMETERS
 /* .ad
 /* .fi
-/*	Changes to \fBmain.cf\fR are picked up automatically, as
-/*	\fBvirtual\fR(8)
+/*	Changes to \fBmain.cf\fR are picked up automatically, as virtual(8)
 /*	processes run for only a limited amount of time. Use the command
 /*	"\fBpostfix reload\fR" to speed up a change.
 /*
 /*	The text below provides only a parameter summary. See
-/*	\fBpostconf\fR(5) for more details including examples.
+/*	postconf(5) for more details including examples.
 /* MAILBOX DELIVERY CONTROLS
 /* .ad
 /* .fi
 /* .IP "\fBvirtual_mailbox_base (empty)\fR"
-/*	A prefix that the \fBvirtual\fR(8) delivery agent prepends to all pathname
+/*	A prefix that the virtual(8) delivery agent prepends to all pathname
 /*	results from $virtual_mailbox_maps table lookups.
 /* .IP "\fBvirtual_mailbox_maps (empty)\fR"
 /*	Optional lookup tables with all valid addresses in the domains that
 /*	match $virtual_mailbox_domains.
 /* .IP "\fBvirtual_minimum_uid (100)\fR"
-/*	The minimum user ID value that the \fBvirtual\fR(8) delivery agent accepts
-/*	as a result from $virtual_uid_maps table lookup.
+/*	The minimum user ID value that the virtual(8) delivery agent accepts
+/*	as a result from \fB$virtual_uid_maps\fR table lookup.
 /* .IP "\fBvirtual_uid_maps (empty)\fR"
-/*	Lookup tables with the per-recipient user ID that the \fBvirtual\fR(8)
+/*	Lookup tables with the per-recipient user ID that the virtual(8)
 /*	delivery agent uses while writing to the recipient's mailbox.
 /* .IP "\fBvirtual_gid_maps (empty)\fR"
-/*	Lookup tables with the per-recipient group ID for \fBvirtual\fR(8) mailbox
+/*	Lookup tables with the per-recipient group ID for virtual(8) mailbox
 /*	delivery.
 /* .PP
 /*	Available in Postfix version 2.0 and later:
@@ -180,14 +169,14 @@
 /* .ad
 /* .fi
 /* .IP "\fBvirtual_mailbox_lock (see 'postconf -d' output)\fR"
-/*	How to lock a UNIX-style \fBvirtual\fR(8) mailbox before attempting
+/*	How to lock a UNIX-style virtual(8) mailbox before attempting
 /*	delivery.
 /* .IP "\fBdeliver_lock_attempts (20)\fR"
 /*	The maximal number of attempts to acquire an exclusive lock on a
-/*	mailbox file or \fBbounce\fR(8) logfile.
+/*	mailbox file or bounce(8) logfile.
 /* .IP "\fBdeliver_lock_delay (1s)\fR"
 /*	The time between attempts to acquire an exclusive lock on a mailbox
-/*	file or \fBbounce\fR(8) logfile.
+/*	file or bounce(8) logfile.
 /* .IP "\fBstale_lock_time (500s)\fR"
 /*	The time after which a stale exclusive mailbox lockfile is removed.
 /* RESOURCE AND RATE CONTROLS
@@ -457,7 +446,7 @@ static void pre_init(char *unused_name, char **unused_argv)
      * file.
      */
     if (var_virt_mailbox_limit) {
-	if (var_virt_mailbox_limit < var_message_limit || var_message_limit == 0)
+	if (var_virt_mailbox_limit < var_message_limit)
 	    msg_fatal("main.cf configuration error: %s is smaller than %s",
 		      VAR_VIRT_MAILBOX_LIMIT, VAR_MESSAGE_LIMIT);
 	set_file_limit(var_virt_mailbox_limit);
